And Now For Something Completely Different
==========================================

**Nagare** is an Open-Source framework, released under the BSD license,
dedicated to rich web applications development in Python.

**Nagare** doesn't follow the statu quo established by the classic frameworks
of the Java, Python, Php and Ruby worlds:

- no templating language
- no explicit URL routing / mapping
- no controllers proliferation
- no manual management of the HTTP request / response cycles
- no global session object
- no REST by default

When you forget all of that, what do you get?

You get a powerful framework dedicated to web applications development, in
opposition to simple content publishing.

You get a truly component based framework where the application is a dynamic
set of autonomous components, each one following its own independent control
flow and maintaining its own private state.

You get a framework where every web page is the composition of views from
several components.

You get a framework where the HTTP connectionless request / response cycle,
the refresh, back and fork actions of the browser, don't break the normal
control flow of the application.

You get a framework with natively integrated Web 2.0 features.

You get a framework where the web applications are developed in the same way
as the desktop applications.

